pub async fn pump_interpreter_to_distributor(
events: Arc<CanonicalEventStream>,
distributor: EventDistributor,
)Expand description
Bridge: drain an interpreter event stream into a distributor, then close.
pub async fn pump_interpreter_to_distributor(
events: Arc<CanonicalEventStream>,
distributor: EventDistributor,
)Bridge: drain an interpreter event stream into a distributor, then close.